package model

import "shylinux.com/x/mysql-story/src/db"

const (
	ID              = "id"
	UID             = "uid"
	NAME            = "name"
	INFO            = "info"
	TYPE            = "type"
	ROLE            = "role"
	STATUS          = "status"
	TITLE           = "title"
	CONTENT         = "content"
	OPERATOR        = "operator"
	CREATED_AT      = "created_at"
	UPDATED_AT      = "updated_at"
	DELETED_AT      = "deleted_at"
	OPEN_ID         = "open_id"
	USER_UID        = "user_uid"
	USER_NAME       = "user_name"
	USER_AVATAR     = "user_avatar"
	USER_PLACE_ROLE = "user_place_role"
	PLACE_UID       = "place_uid"
	PLACE_NAME      = "place_name"
	PLACE_TYPE      = "place_type"
	PLACE_ADDRESS   = "place_address"
	STREET_UID      = "street_uid"
	STREET_NAME     = "street_name"
	CITY_UID        = "city_uid"
	CITY_NAME       = "city_name"
	EVENT_UID       = "event_uid"
	APPLY_UID       = "apply_uid"
	APPLY_STATUS    = "apply_status"
	ALLOW_UID       = "allow_uid"
	ALLOW_STATUS    = "allow_status"
	FROM_USER_UID   = "from_user_uid"
	TO_USER_UID     = "to_user_uid"
	BEGIN_TIME      = "begin_time"
	END_TIME        = "end_time"
	OPERATE         = "operate"
	TABLES          = "tables"
	EMAIL           = "email"
	AVATAR          = "avatar"
	ADDRESS         = "address"
)

type Sess struct {
	db.ModelWithUID
	UserUID string `gorm:"type:char(32);index"`
	IP      string `gorm:"type:char(16)"`
	Agent   string `gorm:"type:varchar(255)"`
}
type User struct {
	db.ModelWithUID
	OpenID string `gorm:"type:char(32);index"`
	Email  string `gorm:"type:varchar(64)"`
	Name   string `gorm:"type:varchar(32)"`
	Avatar string `gorm:"type:varchar(255)"`
}
type UserPlace struct {
	db.ModelWithUID
	UserUID   string `gorm:"type:char(32);index"`
	PlaceUID  string `gorm:"type:char(32);index"`
	Role      uint8  `gorm:"default:0"`
	BeginTime db.Time
	EndTime   db.Time
}
type Place struct {
	db.ModelWithUID
	StreetUID string `gorm:"type:char(32);index"`
	Name      string `gorm:"type:varchar(64)"`
	Address   string `gorm:"type:varchar(255)"`
	Type      uint8  `gorm:"default:0"`
}
type Street struct {
	db.ModelWithUID
	CityUID string `gorm:"type:char(32);index:idx_city"`
	Name    string `gorm:"type:varchar(64);index:idx_city"`
	Info    string
}
type City struct {
	db.ModelWithUID
	Name string `gorm:"type:varchar(64);index"`
}

type Event struct {
	db.ModelWithUID
	PlaceUID string `gorm:"type:char(32);index:idx_place"`
	UserUID  string `gorm:"type:char(32);index:idx_place"`
	Index    string `gorm:"type:varchar(64)"`
	Operate  string `gorm:"type:varchar(32)"`
	Args     string `gorm:"type:varchar(128)"`
	Info     string `gorm:"type:varchar(255)"`
}
type Apply struct {
	db.ModelWithUID
	PlaceUID  string `gorm:"type:char(32);index:idx_place"`
	UserUID   string `gorm:"type:char(32);index:idx_place"`
	Tables    string `gorm:"type:varchar(32)"`
	Status    uint8  `gorm:default:0`
	Role      uint8  `gorm:default:0`
	BeginTime db.Time
	EndTime   db.Time
}
type Allow struct {
	db.ModelWithUID
	ApplyUID string `gorm:"type:char(32);index"`
	UserUID  string `gorm:"type:char(32)"`
	Status   uint8  `gorm:"default:0"`
}
type Message struct {
	db.ModelWithUID
	FromUserUID string `gorm:"type:char(32);index"`
	ToUserUID   string `gorm:"type:char(32);index"`
	PlaceName   string `gorm:"type:varchar(32)"`
	Name        string `gorm:"type:varchar(32)"`
	Icon        string `gorm:"type:varchar(128)"`
	Space       string `gorm:"type:varchar(32)"`
	Index       string `gorm:"type:varchar(64)"`
	Args        string `gorm:"type:varchar(128)"`
	Status      uint   `gorm:"default:0"`
}
type Recent struct {
	db.ModelWithUID
	UserUID string `gorm:"type:char(32);index"`
	Icon    string `gorm:"type:varchar(128)"`
	Name    string `gorm:"type:varchar(32)"`
	Space   string `gorm:"type:varchar(32)"`
	Index   string `gorm:"type:varchar(64)"`
	Args    string `gorm:"type:varchar(128)"`
}
type Service struct {
	db.ModelWithUID
	Icon     string `gorm:"type:varchar(128)"`
	Name     string `gorm:"type:varchar(32)"`
	Index    string `gorm:"type:varchar(64)"`
	Module   string `gorm:"type:varchar(32)"`
	Version  string `gorm:"type:varchar(32)"`
	Domain   string `gorm:"type:varchar(255)"`
	Portal   string `gorm:"type:varchar(255)"`
	Nodename string `gorm:"type:varchar(32)"`
	Nodetype string `gorm:"type:varchar(32)"`
	Pathname string `gorm:"type:varchar(255)"`
	Hostname string `gorm:"type:varchar(32)"`
}
type Support struct {
	db.ModelWithUID
	FromUserUID string `gorm:"type:char(32);index"`
	ToUserUID   string `gorm:"type:char(32);index"`
	Content     string
}

func init() {
	db.CmdModels("",
		&Sess{}, &User{}, &UserPlace{}, &Place{}, &Street{}, &City{},
		Event{}, Apply{}, Allow{}, Message{}, Recent{}, Service{}, Support{},
	)
}
