package gonganxitong

import (
	"shylinux.com/x/ice"
	"shylinux.com/x/icebergs/base/aaa"
	"shylinux.com/x/icebergs/base/ctx"
	"shylinux.com/x/icebergs/base/mdb"
	"shylinux.com/x/icebergs/base/web"
	"shylinux.com/x/toolkits"

	"shylinux.com/x/community/src/gonganxitong/model"
)

type Portal struct {
	Table
	ice.Hash
	user        user
	city        city
	export      string `data:"true"`
	short       string `data:"index"`
	field       string `data:"time,index,name,icons,order,enable,type,role,view"`
	create      string `name:"create index name icons"`
	list        string `name:"list place_uid index uid auto" role:"void"`
	placeCreate string `name:"placeCreate city_name* street_name* place_type*:select place_name* address*" icon:"bi bi-plus-square-dotted" role:"void"`
	placeRemove string `name:"placeRemove uid*" role:"void"`
	scanQRCode  string `name:"scanQRCode type text" icon:"bi bi-qr-code-scan" role:"void"`
	setIcons    string `name:"setIcons icons" icon:"bi bi-info-square"`
}

func (s Portal) Init(m *ice.Message, arg ...string) {
	s.Hash.Init(m, arg...)
	m.Design(s.List, "", kit.JoinWord(s.Keys(s.Place, model.UID), ctx.INDEX, model.UID, ice.AUTO))
}
func (s Portal) Exit(m *ice.Message, arg ...string) {
	s.Hash.Exit(m, arg...)
}
func (s Portal) BeforeMigrate(m *ice.Message, arg ...string) {
}
func (s Portal) AfterMigrate(m *ice.Message, arg ...string) {
	cmd := m.GetCommand()
	m.GoSleep("30ms", func() {
		m.Cmdy(service{}, s.Table.Update, ctx.INDEX, m.PrefixKey(), mdb.NAME, cmd.Help, mdb.ICON, m.Resource(kit.Select(ice.Info.NodeIcon, cmd.Icon)))
	})
}
func (s Portal) Inputs(m *ice.Message, arg ...string) {
	m.Cmdy(s.Place, m.ActionKey(), arg)
}
func (s Portal) Run(m *ice.Message, arg ...string) {
	m.Search(arg[0], func(key string, cmd *ice.Command) {
		sub, role := "", cmd.Role
		if len(arg) > 1 && arg[1] == ctx.ACTION {
			if action, ok := cmd.Actions[arg[2]]; ok {
				sub, role = arg[2], action.Role
			}
		} else {
			if action, ok := cmd.Actions[arg[1]]; ok {
				sub, role = arg[1], action.Role
			}
		}
		if kit.IsIn(role, "", aaa.VOID) {
			kit.If(!ctx.PodCmd(m.Message, arg) && aaa.Right(m.Message, arg), func() { m.Cmdy(arg) })
		} else {
			if !m.Cmdy(arg[0], s.CheckRole, role).IsErr() {
				m.Cmdy(arg)
			}
		}
		if sub != mdb.INPUTS {
			s.Place.RewriteAppend(m)
		}
	})
}
func (s Portal) List(m *ice.Message, arg ...string) {
	if m.Option(mdb.VIEW) == mdb.TABLE {
		s.Hash.List(m, arg...).PushAction(mdb.DETAIL, s.Remove).SortInt(mdb.ORDER)
		return
	}
	if len(arg) == 0 {
		m.Cmdy(s.UserPlace, m.Option(model.USER_UID)).PushAction(s.PlaceRemove).Action(s.PlaceCreate, s.ScanQRCode)
		kit.If(!m.IsErr() && m.Length() == 0, func() { m.EchoInfoButton("", s.PlaceCreate, s.ScanQRCode) })
	} else if len(arg) == 1 {
		msg := m.Cmd(s.Place, s.Table.Select, model.UID, arg[0])
		s.AddRecent(m.Spawn(), arg[0], msg.Append(model.NAME), msg.Append(mdb.ICONS))
		s.Hash.List(m).SortInt(mdb.ORDER)
	} else if len(arg) == 2 {
		msg := m.Cmd(s.Place, s.Table.Select, model.UID, arg[0])
		m.Option(s.Keys(s.Place, model.NAME), msg.Append(model.NAME))
		m.Cmdy(ctx.COMMAND, arg[1]).Push(ctx.ARGS, arg[0])
	} else {
		m.FieldsSetDetail().Cmdy(arg[1], mdb.SELECT, model.UID, arg[2]).PushAction().Action()
	}
	s.Place.RewriteAppend(m)
	s.Display(m, "").DisplayCSS("")
}
func (s Portal) PlaceCreate(m *ice.Message, arg ...string) {
	defer m.ToastProcess()()
	if s.city.FindOrCreateByName(m, arg...); m.IsErr() {
		return
	} else if s.Street.FindOrCreateByName(m, arg...); m.IsErr() {
		return
	}
	name := m.Option(s.Keys(s.Place, model.NAME))
	arg = kit.TransArgKeys(arg, s.Keys(s.Place, model.TYPE), model.TYPE)
	arg = kit.TransArgKeys(arg, s.Keys(s.Place, model.NAME), model.NAME)
	if m.Cmdy(s.Place, s.Create, arg[2:]).IsErr() {
		return
	}
	s.RecordEventWithName(m.Options(mdb.NAME, name), m.Result(), "")
	args := kit.Simple(s.Keys(s.Place, model.UID), m.Result(), m.OptionSimple(model.USER_UID), model.ROLE, UserPlaceCreator)
	m.SetResult().Cmdy(s.UserPlace, s.Create, args)
}
func (s Portal) PlaceRemove(m *ice.Message, arg ...string) {
	defer m.ToastProcess()()
	m.Cmdy(s.UserPlace, s.Delete, m.OptionSimple(model.USER_UID, model.UID))
}
func (s Portal) ScanQRCode(m *ice.Message, arg ...string) {
	defer m.ToastProcess()()
	if m.Option(mdb.TYPE) == mdb.TEXT {
		m.Cmdy(s.UserPlace, s.Create, s.Key(s.Place, model.UID), m.Option(mdb.TEXT), m.OptionSimple(model.USER_UID), model.ROLE, UserPlaceVisitor)
	} else if m.Option(mdb.TYPE) == web.LINK {
		args := m.ParseURL(m.Option(mdb.TEXT))
		if len(args) > 1 && args[1] == m.Prefix("apply") {
			m.Cmdy(s.UserPlace, s.Create, s.Keys(s.Place, model.UID), args[0], m.OptionSimple(model.USER_UID), model.ROLE, UserPlaceVisitor)
		}
	}
}

func init() { ice.TeamCtxCmd(Portal{Table: newTable()}) }

func (s Portal) Create(m *ice.Message, arg ...string) {
	args := []string{ctx.INDEX, m.Option(ctx.INDEX)}
	msg := s.Hash.Select(m.Spawn(), m.Option(ctx.INDEX))
	kit.If(msg.Length() > 0, func() { args = append(args, mdb.TIME, msg.Append(mdb.TIME)) })
	m.Search(m.Option(ctx.INDEX), func(key string, cmd *ice.Command) {
		args = append(args, mdb.NAME, cmd.Help, mdb.ICONS, cmd.Icon)
		kit.For([]string{mdb.ORDER, mdb.TYPE, aaa.ROLE, mdb.VIEW}, func(key string) {
			value := m.Conf(m.Option(ctx.INDEX), kit.Keym(key))
			args = append(args, key, kit.Select(value, msg.Append(key)))
		})
	})
	s.Hash.Create(m, args...)
}
func (s Portal) Show(m *ice.Message, arg ...string) {
	key := m.PrefixKey()
	m.GoSleep("300ms", func() { m.Cmd(m.Prefix(web.PORTAL), s.Create, ctx.INDEX, key) })
}
func (s Portal) Link(m *ice.Message, arg ...string) string {
	return m.MergePodCmd("", m.Prefix(web.PORTAL)) + "#" + kit.TrimSuffix(kit.Join([]string{arg[0], kit.Select(m.Prefix("apply"), arg, 1), kit.Select("", arg, 2)}, ":"), ":")
}

func init() { ice.TeamCtxCmd(Portal{Table: newTable()}) }
